@@ -76,6 +76,7 @@ struct _GdauiDataProxyInfoPriv
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
+static GtkCssProvider *css_provider = NULL;
 
 /* properties */
 enum {
@@ -104,7 +105,7 @@ gdaui_data_proxy_info_get_type (void)
 			0
 		};
 
-		type = g_type_register_static (GTK_TYPE_HBOX, "GdauiDataProxyInfo", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "GdauiDataProxyInfo", &info, 0);
 	}
 
 	return type;
@@ -464,18 +465,16 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 {
 	GtkWidget *wid;
 	GdauiDataProxyInfoFlag flags = info->priv->flags;
-	static gboolean rc_done = FALSE;
 
-	if (!rc_done) {
-                rc_done = TRUE;
-                gtk_rc_parse_string ("style \"gdaui-data-proxy-info-style\"\n"
-                                     "{\n"
-                                     "GtkToolbar::shadow-type = GTK_SHADOW_NONE\n"
-				     "GtkSpinButton::shadow-type = GTK_SHADOW_NONE\n"
-                                     "xthickness = 0\n"
-                                     "ythickness = 0\n"
-                                     "}\n"
-                                     "widget \"*.gdaui-data-proxy-info\" style \"gdaui-data-proxy-info-style\"");
+	if (!css_provider) {
+		css_provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (css_provider,
+						 "* {\n"
+						 "-GtkToolbar-shadow-type : none;\n"
+						 "-GtkSpinButton-shadow-type : none;\n"
+						 "xthickness : 0;\n"
+						 "ythickness : 0}",
+						 -1, NULL);
         }
 
 	if (! info->priv->data_proxy)
@@ -488,22 +487,8 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 		gtk_widget_unparent (info->priv->tool_item);
 	}
 
-	gboolean row_modif_needed = FALSE;
-	gboolean row_move_needed = FALSE;
-	gboolean chunk_change_needed = FALSE;
 	gboolean ensure_update = FALSE;
 
-	if (flags & (GDAUI_DATA_PROXY_INFO_ROW_MODIFY_BUTTONS |
-		     GDAUI_DATA_PROXY_INFO_ROW_MOVE_BUTTONS |
-		     GDAUI_DATA_PROXY_INFO_CHUNCK_CHANGE_BUTTONS)) {
-		if (flags & GDAUI_DATA_PROXY_INFO_ROW_MODIFY_BUTTONS)
-			row_modif_needed = TRUE;
-		if (flags & GDAUI_DATA_PROXY_INFO_ROW_MOVE_BUTTONS)
-			row_move_needed = TRUE;
-		if (flags & GDAUI_DATA_PROXY_INFO_CHUNCK_CHANGE_BUTTONS)
-			chunk_change_needed = TRUE;
-	}
-
 	if (info->priv->uimanager) {
 		if (info->priv->merge_id_row_modif) {
 			gtk_ui_manager_remove_ui (info->priv->uimanager, info->priv->merge_id_row_modif);
@@ -570,7 +555,9 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 	g_object_ref_sink (info->priv->buttons_bar);
 	gtk_toolbar_set_icon_size (GTK_TOOLBAR (info->priv->buttons_bar), GTK_ICON_SIZE_MENU);
 	g_object_set (G_OBJECT (info->priv->buttons_bar), "toolbar-style", GTK_TOOLBAR_ICONS, NULL);
-	gtk_widget_set_name (info->priv->buttons_bar, "gdaui-data-proxy-info");
+	gtk_style_context_add_provider (gtk_widget_get_style_context (info->priv->buttons_bar),
+					GTK_STYLE_PROVIDER (css_provider),
+					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	gtk_box_pack_start (GTK_BOX (info), info->priv->buttons_bar, TRUE, TRUE, 0);
 	gtk_widget_show (info->priv->buttons_bar);
 
@@ -600,12 +587,15 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 						 pango_font_description_get_size (fd) * .8);
 
 		if (flags & GDAUI_DATA_PROXY_INFO_ROW_MOVE_BUTTONS) {
-			toolwid = gtk_hbox_new (FALSE, 0);
-
+			toolwid = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+			
 			/* read-write spin counter (mainly for forms) */
 			wid = gtk_spin_button_new_with_range (0, 1, 1);
-			gtk_widget_modify_font (wid, fdc);
-			gtk_widget_set_name (wid, "gdaui-data-proxy-info");
+
+			gtk_widget_override_font (wid, fdc);
+			gtk_style_context_add_provider (gtk_widget_get_style_context (wid),
+							GTK_STYLE_PROVIDER (css_provider),
+							GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 			gtk_spin_button_set_digits (GTK_SPIN_BUTTON (wid), 0);
 			gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (wid), TRUE);
 			gtk_box_pack_start (GTK_BOX (toolwid), wid, FALSE, TRUE, 2);
@@ -616,14 +606,14 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 
 			/* rows counter */
 			wid = gtk_label_new (" /?");
-			gtk_widget_modify_font (wid, fdc);
+			gtk_widget_override_font (wid, fdc);
 			info->priv->current_sample = wid;
 			gtk_box_pack_start (GTK_BOX (toolwid), wid, FALSE, FALSE, 2);
 		}
 		else {
 			/* read-only counter (mainly for grids) */
 			wid = gtk_label_new ("? - ? /?");
-			gtk_widget_modify_font (wid, fdc);
+			gtk_widget_override_font (wid, fdc);
 			info->priv->current_sample = wid;
 			toolwid = wid;
 		}
