@@ -66,6 +66,7 @@ static GObjectClass  *parent_class = NULL;
 
 struct _GdaStatementPrivate {
 	GdaSqlStatement *internal_struct;
+	GType           *requested_types;
 };
 
 /* signals */
@@ -178,6 +179,7 @@ gda_statement_init (GdaStatement * stmt)
 {
 	stmt->priv = g_new0 (GdaStatementPrivate, 1);
 	stmt->priv->internal_struct = NULL;
+	stmt->priv->requested_types = NULL;
 }
 
 /**
@@ -231,6 +233,10 @@ gda_statement_dispose (GObject *object)
 
 	stmt = GDA_STATEMENT (object);
 	if (stmt->priv) {
+		if (stmt->priv->requested_types) {
+			g_free (stmt->priv->requested_types);
+			stmt->priv->requested_types = NULL;
+		}
 		if (stmt->priv->internal_struct) {
 			gda_sql_statement_free (stmt->priv->internal_struct);
 			stmt->priv->internal_struct = NULL;
@@ -276,6 +282,10 @@ gda_statement_set_property (GObject *object,
 				gda_sql_statement_free (stmt->priv->internal_struct);
 				stmt->priv->internal_struct = NULL;
 			}
+			if (stmt->priv->requested_types) {
+				g_free (stmt->priv->requested_types);
+				stmt->priv->requested_types = NULL;
+			}
 			stmt->priv->internal_struct = gda_sql_statement_copy (g_value_get_pointer (value));
 			g_signal_emit (stmt, gda_statement_signals [RESET], 0);
 			break;
@@ -495,7 +505,30 @@ get_params_foreach_func (GdaSqlAnyPart *node, GdaSet **params, GError **error)
 			      "description", pspec->descr, NULL);
 		gda_holder_set_not_null (h, ! pspec->nullok);
 		if (((GdaSqlExpr*) node)->value) {
-			gda_holder_set_default_value (h, ((GdaSqlExpr*) node)->value);
+			/* Expr's value is "SQL encoded" => we need to convert it to a real value */
+			GValue *evalue;
+			evalue = ((GdaSqlExpr*) node)->value;
+			if (G_VALUE_TYPE (evalue) == G_TYPE_STRING) {
+				GdaDataHandler *dh;
+				GValue *value;
+				dh = gda_data_handler_get_default (pspec->g_type);
+				if (!dh) {
+					g_set_error (error, GDA_STATEMENT_ERROR, GDA_STATEMENT_PARAM_TYPE_ERROR,
+						     _("Can't handle default value of type '%s'"),
+						     gda_g_type_to_string (pspec->g_type));
+					g_object_unref (h);
+					return FALSE;
+				}
+				value = gda_data_handler_get_value_from_sql (dh,
+									     g_value_get_string (evalue),
+									     pspec->g_type);
+				if (!value)
+					value = gda_value_new_default (g_value_get_string (evalue));
+				gda_holder_set_default_value (h, value);
+				gda_value_free (value);
+			}
+			else
+				gda_holder_set_default_value (h, ((GdaSqlExpr*) node)->value);
 			gda_holder_set_value_to_default (h);
 		}
 		gda_set_add_holder (*params, h);
@@ -543,6 +576,57 @@ gda_statement_get_parameters (GdaStatement *stmt, GdaSet **out_params, GError **
 	return TRUE;
 }
 
+/*
+ * _gda_statement_get_requested_types:
+ * @stmt: a #GdaStatement
+ *
+ * Returns: a new #GType, suitable to use with gda_connection_statement_execute_select_full(), or %NULL
+ */
+const GType *
+_gda_statement_get_requested_types (GdaStatement *stmt)
+{
+	if (! stmt->priv || ! stmt->priv->internal_struct)
+		return NULL;
+	if (stmt->priv->requested_types)
+		return stmt->priv->requested_types;
+	if (stmt->priv->internal_struct->stmt_type != GDA_SQL_STATEMENT_SELECT)
+		return NULL;
+
+	GdaSqlStatementSelect *selst;
+	GSList *list;
+	GArray *array = NULL;
+ rewind:
+	selst = (GdaSqlStatementSelect*) stmt->priv->internal_struct->contents;
+	for (list = selst->expr_list; list; list = list->next) {
+		GdaSqlExpr *expr;
+		GType type = G_TYPE_INVALID;
+		expr = ((GdaSqlSelectField*) list->data)->expr;
+		if (expr->cast_as && *expr->cast_as)
+			type = gda_g_type_from_string (expr->cast_as);
+		if (array) {
+			if (type == G_TYPE_INVALID)
+				type = 0;
+			g_array_append_val (array, type);
+		}
+		else if (type != G_TYPE_INVALID) {
+			array = g_array_new (TRUE, FALSE, sizeof (GType));
+			goto rewind;
+		}
+	}
+	if (array) {
+		GType *retval;
+		guint len;
+		len = array->len;
+		retval = (GType*) g_array_free (array, FALSE);
+		retval [len] = G_TYPE_NONE;
+		stmt->priv->requested_types = retval;
+		return retval;
+	}
+	else
+		return NULL;
+}
+
+
 /*
  * SQL rendering
  */
@@ -700,9 +784,14 @@ default_render_value (const GValue *value, GdaSqlRenderingContext *context, GErr
 			dh = gda_data_handler_get_default (G_VALUE_TYPE (value));
 
 		if (!dh) {
-			g_set_error (error, GDA_SQL_ERROR, GDA_SQL_STRUCTURE_CONTENTS_ERROR,
-				     _("No data handler for type '%s'"), g_type_name (G_VALUE_TYPE (value)));
-			return NULL;
+			if (G_VALUE_TYPE (value) == GDA_TYPE_DEFAULT)
+				return g_strdup ("DEFAULT");
+			else {
+				g_set_error (error, GDA_SQL_ERROR, GDA_SQL_STRUCTURE_CONTENTS_ERROR,
+					     _("No data handler for type '%s'"),
+					     g_type_name (G_VALUE_TYPE (value)));
+				return NULL;
+			}
 		}
 		return gda_data_handler_get_sql_from_value (dh, value);
 	}
@@ -1028,7 +1117,9 @@ default_render_compound (GdaSqlStatementCompound *stmt, GdaSqlRenderingContext *
 		case GDA_SQL_ANY_STMT_SELECT:
 			str = context->render_select (GDA_SQL_ANY_PART (sqlstmt->contents), context, error);
 			if (!str) goto err;
+			g_string_append_c (string, '(');
 			g_string_append (string, str);
+			g_string_append_c (string, ')');
 			g_free (str);
 			break;
 		case GDA_SQL_ANY_STMT_COMPOUND:
@@ -1304,7 +1395,10 @@ default_render_param_spec (GdaSqlParamSpec *pspec, GdaSqlExpr *expr, GdaSqlRende
 
 		if (flag & GDA_STATEMENT_SQL_PARAMS_LONG) {
 			if (expr->value) {
-				str = context->render_value (expr->value, context, error);
+				if (G_VALUE_TYPE (expr->value) == G_TYPE_STRING)
+					str = g_value_dup_string (expr->value);
+				else
+					str = context->render_value (expr->value, context, error);
 				if (!str) {
 					g_free (quoted_pname);
 					goto err;
@@ -1430,8 +1524,33 @@ default_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context, gboolean
 		gchar *tmp;
 		tmp = context->render_operation (GDA_SQL_ANY_PART (expr->cond), context, error);
 		if (!tmp) goto err;
-		str = g_strconcat ("(", tmp, ")", NULL);
-		g_free (tmp);
+		str = NULL;
+		if (GDA_SQL_ANY_PART (expr)->parent) {
+			if (GDA_SQL_ANY_PART (expr)->parent->type == GDA_SQL_ANY_STMT_SELECT) {
+				GdaSqlStatementSelect *selst;
+				selst = (GdaSqlStatementSelect*) (GDA_SQL_ANY_PART (expr)->parent);
+				if ((expr == selst->where_cond) ||
+				    (expr == selst->having_cond))
+					str = tmp;
+			}
+			else if (GDA_SQL_ANY_PART (expr)->parent->type == GDA_SQL_ANY_STMT_DELETE) {
+				GdaSqlStatementDelete *delst;
+				delst = (GdaSqlStatementDelete*) (GDA_SQL_ANY_PART (expr)->parent);
+				if (expr == delst->cond)
+					str = tmp;
+			}
+			else if (GDA_SQL_ANY_PART (expr)->parent->type == GDA_SQL_ANY_STMT_UPDATE) {
+				GdaSqlStatementUpdate *updst;
+				updst = (GdaSqlStatementUpdate*) (GDA_SQL_ANY_PART (expr)->parent);
+				if (expr == updst->cond)
+					str = tmp;
+			}
+		}
+
+		if (!str) {
+			str = g_strconcat ("(", tmp, ")", NULL);
+			g_free (tmp);
+		}
 	}
 	else if (expr->select) {
 		gchar *str1;
@@ -1606,7 +1725,7 @@ default_render_operation (GdaSqlOperation *op, GdaSqlRenderingContext *context,
 			goto out;
 		}
 		sqlop->sql = str;
-		if (expr->cond || expr->case_s || expr->select)
+		if (expr->case_s || expr->select)
 			sqlop->is_composed = TRUE;
 		sql_list = g_slist_prepend (sql_list, sqlop);
 	}
@@ -1835,6 +1954,16 @@ default_render_case (GdaSqlCase *case_s, GdaSqlRenderingContext *context, GError
 	return NULL;
 }
 
+static gboolean
+alias_is_quoted (const gchar *alias)
+{
+	g_assert (alias);
+	if ((*alias == '\'') || (*alias == '"'))
+		return TRUE;
+	else
+		return FALSE;
+}
+
 static gchar *
 default_render_select_field (GdaSqlSelectField *field, GdaSqlRenderingContext *context, GError **error)
 {
@@ -1853,8 +1982,21 @@ default_render_select_field (GdaSqlSelectField *field, GdaSqlRenderingContext *c
 	g_string_append (string, str);
 	g_free (str);
 
-	if (field->as)
-		g_string_append_printf (string, " AS %s", field->as);
+	if (field->as) {
+		if (! alias_is_quoted (field->as)) {
+			GdaConnectionOptions cncoptions = 0;
+			gchar *tmp;
+			if (context->cnc)
+				g_object_get (G_OBJECT (context->cnc), "options", &cncoptions, NULL);
+			tmp = gda_sql_identifier_quote (field->as, context->cnc,
+							context->provider, FALSE,
+							cncoptions & GDA_CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
+			g_string_append_printf (string, " AS %s", tmp);
+			g_free (tmp);
+		}
+		else
+			g_string_append_printf (string, " AS %s", field->as);
+	}
 
 	str = string->str;
 	g_string_free (string, FALSE);
@@ -1894,8 +2036,21 @@ default_render_select_target (GdaSqlSelectTarget *target, GdaSqlRenderingContext
 		g_free (str);
 	}
 
-	if (target->as)
-		g_string_append_printf (string, " AS %s", target->as);
+	if (target->as) {
+		if (! alias_is_quoted (target->as)) {
+			GdaConnectionOptions cncoptions = 0;
+			gchar *tmp;
+			if (context->cnc)
+				g_object_get (G_OBJECT (context->cnc), "options", &cncoptions, NULL);
+			tmp = gda_sql_identifier_quote (target->as, context->cnc,
+							context->provider, FALSE,
+							cncoptions & GDA_CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
+			g_string_append_printf (string, " AS %s", tmp);
+			g_free (tmp);
+		}
+		else
+			g_string_append_printf (string, " AS %s", target->as);
+	}
 
 	str = string->str;
 	g_string_free (string, FALSE);
