@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2009 Murray Cumming <murrayc@murrayc.com>
  *
@@ -33,7 +33,7 @@
 gchar *
 gda_sql_value_stringify (const GValue *value)
 {
-        if (value && G_IS_VALUE (value)) {
+        if (value && !GDA_VALUE_HOLDS_NULL (value)) {
                 if (g_value_type_transformable (G_VALUE_TYPE (value), G_TYPE_STRING)) {
                         GValue *string;
                         gchar *str;
@@ -41,8 +41,7 @@ gda_sql_value_stringify (const GValue *value)
                         string = g_value_init (g_new0 (GValue, 1), G_TYPE_STRING);
                         g_value_transform (value, string);
                         str = g_value_dup_string (string);
-                        g_value_unset (string);
-			g_free (string);
+			gda_value_free (string);
                         return str;
                 }
                 else {
@@ -86,6 +85,7 @@ _remove_quotes (gchar *str)
 	if ((delim != '\'') && (delim != '"'))
 		return str;
 
+
         total = strlen (str);
         if (str[total-1] == delim) {
 		/* string is correctly terminated by a double quote */
@@ -112,17 +112,7 @@ _remove_quotes (gchar *str)
                                 return str;
                         }
                 }
-                else if (*ptr == '"') {
-                        if (*(ptr+1) == '"') {
-                                g_memmove (ptr+1, ptr+2, total - offset);
-                                offset += 2;
-                        }
-                        else {
-				*str = 0;
-				return str;
-                        }
-                }
-		else if (*ptr == '\\') {
+                if (*ptr == '\\') {
                         if (*(ptr+1) == '\\') {
                                 g_memmove (ptr+1, ptr+2, total - offset);
                                 offset += 2;
@@ -149,18 +139,18 @@ _remove_quotes (gchar *str)
 }
 
 /**
- * gda_sql_identifier_add_quotes
+ * gda_sql_identifier_force_quotes
  * @str: an SQL identifier
  *
- * Add double quotes around the @str identifier. Use the gda_sql_identifier_needs_quotes()
- * function to tell if an identifier needs to be quoted.
+ * Add double quotes around the @str identifier. This function is normally used only by database provider's
+ * implementation.
  *
- * Returns: a new string
+ * For other uses, see gda_sql_identifier_quote().
  *
- * Deprecated: 4.0.3: Use gda_sql_identifier_quote() instead.
+ * Since: 5.0
  */
 gchar *
-gda_sql_identifier_add_quotes (const gchar *str)
+gda_sql_identifier_force_quotes (const gchar *str)
 {
 	gchar *retval, *rptr;
 	const gchar *sptr;
@@ -174,7 +164,7 @@ gda_sql_identifier_add_quotes (const gchar *str)
 	*retval = '"';
 	for (rptr = retval+1, sptr = str; *sptr; sptr++, rptr++) {
 		if (*sptr == '"') {
-			*rptr = '"';
+			*rptr = '\\';
 			rptr++;
 			*rptr = *sptr;
 		}
@@ -284,16 +274,9 @@ _string_is_identifier (const gchar *str)
 		ptr = str + 1;
 	else
 		ptr = str;
-	for (; IdChar(*ptr) ||
-		     (*ptr == '*') ||
-		     (*ptr == '.') ||
-		     (*ptr == '-') ||
-		     ((*ptr == '"') && (ptr[1] == '"')) ||
-		     (((*ptr == '"') || (*ptr == '`')) && ptr[1] == 0);
-	     ptr++) {
-		if ((*ptr == '"') && (ptr[1] == '"'))
-			ptr++;
-	}
+	for (; 
+	     IdChar(*ptr) || (*ptr == '*') || (*ptr == '.') || (*ptr == '-') || (((*ptr == '"') || (*ptr == '`')) && ptr[1] == 0); 
+	     ptr++);
 	if (*ptr) 
 		return FALSE;
 	if (((*str == '"') && (ptr[-1] == '"')) ||
@@ -309,82 +292,32 @@ _string_is_identifier (const gchar *str)
 }
 
 /**
- * gda_sql_identifier_needs_quotes
- * @str: an SQL identifier
- *
- * Tells if @str needs to be quoted before using it in an SQL statement. To actually add quotes,
- * use gda_sql_identifier_add_quotes().
- *
- * To determine if quotes are needed: the following rules are applied:
- * <itemizedlist>
- *  <listitem><para>If the 1st character is a digit, then %TRUE is returned</para></listitem>
- *  <listitem><para>If there are mixed lower and upper case letters, then %TRUE is returned</para></listitem>
- *  <listitem><para>If there are other characters than digits, letters and the '_', '$' and '#', then %TRUE is returned</para></listitem>
- *  <listitem><para>Otherwise %FALSE is returned</para></listitem>
- * </itemizedlist>
- *
- * Returns: TRUE if @str needs some quotes
- *
- * Deprecated: 4.0.3: Not needed anymore because of the gda_sql_identifier_quote() function.
- */
-gboolean
-gda_sql_identifier_needs_quotes (const gchar *str)
-{
-	const gchar *ptr;
-	gchar icase = 0;
-
-	g_return_val_if_fail (str, FALSE);
-	for (ptr = str; *ptr; ptr++) {
-		/* quote if 1st char is a number */
-		if ((*ptr <= '9') && (*ptr >= '0')) {
-			if (ptr == str)
-				return TRUE;
-			continue;
-		}
-		if ((*ptr >= 'A') && (*ptr <= 'Z')) {
-			if (icase == 0) /* first alpha char encountered */
-				icase = 'U';
-			else if (icase == 'L') /* @str has mixed case */
-				return TRUE;
-			continue;
-		}
-		if ((*ptr >= 'a') && (*ptr <= 'z')) {
-			if (icase == 0) /* first alpha char encountered */
-				icase = 'L';
-			else if (icase == 'U')
-				return TRUE; /* @str has mixed case */
-			continue;
-		}
-		if ((*ptr != '$') && (*ptr != '_') && (*ptr != '#'))
-			return TRUE;
-	}
-	return FALSE;
-}
-
-/**
- * gda_sql_identifier_remove_quotes
+ * gda_sql_identifier_prepare_for_compare
  * @str: a quoted string
  *
  * Prepares @str to be compared:
  * <itemizedlist>
- *  <listitem><para>if surrounded by double quotes or single quotes, then just remove the quotes</para></listitem>
- *  <listitem><para>otherwise convert to lower case</para></listitem>
+ * <listitem><para>if surrounded by double quotes or single quotes, then just remove the quotes</para></listitem>
+ * <listitem><para>otherwise convert to lower case</para></listitem>
  * </itemizedlist>
  *
  * The quoted string:
  * <itemizedlist>
- *  <listitem><para>must start and finish with the same single or double quotes character</para></listitem>
- *  <listitem><para>can contain the delimiter character (the single or double quotes) in the string if every instance of it is preceeded with a backslash character or with the delimiter character itself</para></listitem>
+ *   <listitem><para>must start and finish with the same single or double quotes character</para></listitem>
+ *   <listitem><para>can contain the delimiter character (the single or double quotes) in the string if every instance
+ *     of it is preceeded with a backslash character or with the delimiter character itself</para></listitem>
  * </itemizedlist>
  *
+ * This function is normally used only by database provider's implementation.
+ *
  * WARNING: @str must NOT be a composed identifier (&lt;part1&gt;."&lt;part2&gt;" for example)
  * 
  * Returns: @str
- * 
- * Deprecated: 4.0.3: Not needed anymore because of the gda_sql_identifier_quote() function.
+ *
+ * Since: 5.0
  */
 gchar *
-gda_sql_identifier_remove_quotes (gchar *str)
+gda_sql_identifier_prepare_for_compare (gchar *str)
 {
 	if (!str)
 		return NULL;
@@ -453,13 +386,8 @@ _split_identifier_string (gchar *str, gchar **remain, gchar **last)
 	}
 
 	for (ptr = str + strlen (str) - 1; ptr >= str; ptr--) {
-		if (*ptr == '"') {
-			if ((ptr > str) && (ptr[-1] == '"')) {
-				ptr--;
-				continue;
-			}
+		if (*ptr == '"') 
 			inq = !inq;
-		}
 		else if ((*ptr == '.') && !inq) {
 			*ptr = 0;
 			*remain = str;
