@@ -379,9 +379,6 @@ BrowserWindow*
 browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 {
 	BrowserWindow *bwin;
-	const gchar *cncname;
-	const GdaDsnInfo *dsn;
-	GString *title;
 
 	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
 
@@ -390,19 +387,11 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	g_signal_connect (bcnc, "transaction-status-changed",
 			  G_CALLBACK (transaction_status_changed_cb), bwin);
 
-	dsn = browser_connection_get_information (bcnc);
-	cncname = browser_connection_get_name (bcnc);
-	title = g_string_new (_("Connection"));
-	g_string_append (title, " ");
-	g_string_append_printf (title, "'%s'", cncname ? cncname : _("unnamed"));
-	if (dsn) {
-		if (dsn->name)
-			g_string_append_printf (title, ", %s '%s'", _("data source"), dsn->name);
-		if (dsn->provider)
-			g_string_append_printf (title, " (%s)", dsn->provider);
-	}
-	gtk_window_set_title (GTK_WINDOW (bwin), title->str);
-	g_string_free (title, TRUE);
+	gchar *tmp;
+	tmp = browser_connection_get_long_name (bcnc);
+	gtk_window_set_title (GTK_WINDOW (bwin), tmp);
+	g_free (tmp);
+
 	gtk_window_set_default_size ((GtkWindow*) bwin, 900, 650);
 	g_signal_connect (G_OBJECT (bwin), "delete-event",
                           G_CALLBACK (delete_event), bwin);
@@ -498,6 +487,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	gtk_container_add (GTK_CONTAINER (ti), svbox);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), ti, -1);
         gtk_widget_show_all (GTK_WIDGET (ti));
+	gtk_widget_hide (GTK_WIDGET (spinner));
 	bwin->priv->spinner = spinner;
 
 	/* statusbar */
@@ -547,7 +537,8 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
         bwin->priv->perspectives_nb = (GtkNotebook*) gtk_notebook_new ();
         g_object_ref (bwin->priv->perspectives_nb);
         gtk_notebook_set_show_tabs (bwin->priv->perspectives_nb, FALSE);
-	gtk_container_add (GTK_CONTAINER (vbox), (GtkWidget*) bwin->priv->perspectives_nb);
+	gtk_box_pack_start (GTK_BOX (vbox), (GtkWidget*) bwin->priv->perspectives_nb,
+			    TRUE, TRUE, 0);
 
 	pers->page_number = gtk_notebook_append_page (bwin->priv->perspectives_nb,
 						      GTK_WIDGET (pers->perspective_widget), NULL);
@@ -743,9 +734,10 @@ connection_busy_cb (BrowserConnection *bcnc, gboolean is_busy, gchar *reason, Br
 		gtk_action_set_sensitive (action, !is_busy);
 	}
 
-	const gchar *cncname;
-	cncname = browser_connection_get_name (bcnc);
+	gchar *cncname;
+	cncname = browser_connection_get_long_name (bcnc);
 	action = gtk_action_group_get_action (bwin->priv->cnc_agroup, cncname);
+	g_free (cncname);
 	if (action)
 		gtk_action_set_sensitive (action, !is_busy);
 }
@@ -755,20 +747,21 @@ static void
 connection_added_cb (G_GNUC_UNUSED BrowserCore *bcore, BrowserConnection *bcnc, BrowserWindow *bwin)
 {
 	GtkAction *action;
-	const gchar *cncname;
+	gchar *cncname;
 	guint mid;
 
 	mid = gtk_ui_manager_new_merge_id (bwin->priv->ui_manager);
-	cncname = browser_connection_get_name (bcnc);
+	cncname = browser_connection_get_long_name (bcnc);
 	action = gtk_action_new (cncname, cncname, NULL, NULL);
 	gtk_action_group_add_action (bwin->priv->cnc_agroup, action);
 	guint *amid = g_new (guint, 1);
 	*amid = mid;
 	g_object_set_data_full (G_OBJECT (action), "mid", amid, g_free);
 	
-	gtk_ui_manager_add_ui (bwin->priv->ui_manager, mid,  "/MenuBar/Window/WindowNewOthers/CncList",
+	gtk_ui_manager_add_ui (bwin->priv->ui_manager, mid, "/MenuBar/Window/WindowNewOthers/CncList",
 			       cncname, cncname,
-			       GTK_UI_MANAGER_AUTO, FALSE);	
+			       GTK_UI_MANAGER_AUTO, FALSE);
+	g_free (cncname);
 	g_signal_connect (action, "activate",
 			  G_CALLBACK (window_new_with_cnc_cb), bwin);
 	g_object_set_data (G_OBJECT (action), "bcnc", bcnc);
@@ -790,11 +783,12 @@ connection_removed_cb (G_GNUC_UNUSED BrowserCore *bcore, BrowserConnection *bcnc
 {
 	GtkAction *action;
 	gchar *path;
-	const gchar *cncname;
+	gchar *cncname;
 	guint *mid;
 
-	cncname = browser_connection_get_name (bcnc);
+	cncname = browser_connection_get_long_name (bcnc);
 	path = g_strdup_printf ("/MenuBar/Window/WindowNewOthers/CncList/%s", cncname);
+	g_free (cncname);
 	action = gtk_ui_manager_get_action (bwin->priv->ui_manager, path);
 	g_free (path);
 	g_assert (action);
@@ -1296,7 +1290,7 @@ browser_window_get_connection (BrowserWindow *bwin)
 /*
  * perspective_data_new
  * @bwin: a #BrowserWindow in which the perspective will be
- * @factory: a #BrowserPerspectiveFactory, or %NULL
+ * @factory: (allow-none): a #BrowserPerspectiveFactory, or %NULL
  *
  * Creates a new #PerspectiveData structure, it increases @bcnc's reference count.
  *
@@ -1444,8 +1438,7 @@ static GHashTable *hidden_contexts = NULL;
 static void
 hidden_contexts_foreach_save (const gchar *context, G_GNUC_UNUSED gint value, xmlNodePtr root)
 {
-	xmlNodePtr node;
-	node = xmlNewChild (root, NULL, BAD_CAST "hide-notice", BAD_CAST context);
+	xmlNewChild (root, NULL, BAD_CAST "hide-notice", BAD_CAST context);
 }
 
 static void
@@ -1615,8 +1608,8 @@ browser_window_show_notice (BrowserWindow *bwin, GtkMessageType type, const gcha
  * browser_window_customize_perspective_ui
  * @bwin: a #BrowserWindow
  * @bpers: the #BrowserPerspective concerned
- * @actions_group: a #GtkActionGroup object, or %NULL
- * @ui_info: a merge UI string, or %NULL. See gtk_ui_manager_add_ui_from_string()
+ * @actions_group: (allow-none): a #GtkActionGroup object, or %NULL
+ * @ui_info: (allow-none): a merge UI string, or %NULL. See gtk_ui_manager_add_ui_from_string()
  *
  * Customizes a UI specific to the @bpers perspective. Any
  * previous customization is removed, replaced by the new requested one.
