@@ -1,23 +1,20 @@
 /*
- * Copyright (C) 2009 - 2010 The GNOME Foundation
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -96,6 +93,8 @@ favorite_selector_init (FavoriteSelector *tsel,	G_GNUC_UNUSED FavoriteSelectorCl
 {
 	tsel->priv = g_new0 (FavoriteSelectorPrivate, 1);
 	tsel->priv->idle_update_favorites = 0;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (tsel), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -141,7 +140,7 @@ favorite_selector_get_type (void)
 			(GInstanceInitFunc) favorite_selector_init,
 			0
 		};
-		type = g_type_register_static (GTK_TYPE_VBOX, "FavoriteSelector",
+		type = g_type_register_static (GTK_TYPE_BOX, "FavoriteSelector",
 					       &info, 0);
 	}
 	return type;
@@ -236,10 +235,9 @@ favorite_selector_new (BrowserConnection *bcnc)
 	g_object_unref (manager);
 
 	/* update the tree's contents */
-	if (! gda_tree_update_all (tsel->priv->tree, NULL)) {
-		if (tsel->priv->idle_update_favorites == 0)
-			tsel->priv->idle_update_favorites = g_idle_add ((GSourceFunc) idle_update_favorites, tsel);
-	}
+	if (tsel->priv->idle_update_favorites == 0)
+		tsel->priv->idle_update_favorites = g_idle_add ((GSourceFunc) idle_update_favorites,
+								tsel);
 
 	/* header */
 	GtkWidget *label;
